@@ -207,10 +207,10 @@ setup_ranges (GladeXML *dialog, GConfChangeSet *changeset)
 
 		adjustment->value = ranges [i].default_val;
 		adjustment->lower = ranges [i].min_val;
-		adjustment->upper = ranges [i].max_val + ranges [i].step_size;
+		adjustment->upper = ranges [i].max_val;
 		adjustment->step_increment = ranges [i].step_size;
 		adjustment->page_increment = ranges [i].step_size;
-		adjustment->page_size = ranges [i].step_size;
+		adjustment->page_size = 0;
 
 		gtk_adjustment_changed (adjustment);
 		gtk_spin_button_configure (GTK_SPIN_BUTTON (spin), adjustment,
@@ -386,6 +386,8 @@ load_CDE_file (GtkFileChooser *fchooser)
 	found |= xrm_get_bool (client, &db, CONFIG_ROOT "/enable",
 		"*EnableAccessXToggle.set",	"AccessX*ToggleButtonGadget.XmCSet");
 
+	g_object_unref (client);
+
 	if (!found) {
 		/* it would be nice to have a better message bu that would
 		 * break string freeze
@@ -460,6 +462,7 @@ setup_accessX_dialog (GConfChangeSet *changeset)
 
 	client = gconf_client_get_default ();
 	gconf_client_add_dir (client, CONFIG_ROOT, GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
+	g_object_unref (client);
 
 	setup_dialog (dialog, changeset);
 
