@@ -1,7 +1,7 @@
 /*
  *  Authors: Rodney Dawes <dobey@ximian.com>
  *
- *  Copyright 2003-2004 Novell, Inc. (www.novell.com)
+ *  Copyright 2003-2005 Novell, Inc. (www.novell.com)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of version 2 of the GNU General Public License
@@ -94,11 +94,21 @@ static void gnome_wp_xml_load_xml (GnomeWPCapplet * capplet,
 				   const gchar * filename) {
   xmlDoc * wplist;
   xmlNode * root, * list, * wpa;
+  gchar * nodelang;
+  const gchar * const * syslangs;
   GdkColor color1, color2;
   GnomeWPItem * item;
+  gint i;
+
+#if GLIB_CHECK_VERSION (2, 6, 0)
+  syslangs = g_get_language_names ();
+#endif
 
   wplist = xmlParseFile (filename);
 
+  if (!wplist)
+    return;
+
   root = xmlDocGetRootElement (wplist);
 
   for (list = root->children; list != NULL; list = list->next) {
@@ -111,14 +121,28 @@ static void gnome_wp_xml_load_xml (GnomeWPCapplet * capplet,
 
       for (wpa = list->children; wpa != NULL; wpa = wpa->next) {
 	if (!strcmp (wpa->name, "filename")) {
-	  if (wpa->last != NULL) {
+	  if (wpa->last != NULL && wpa->last->content != NULL) {
 	    wp->filename = g_strdup (g_strstrip (wpa->last->content));
 	  } else {
 	    break;
 	  }
 	} else if (!strcmp (wpa->name, "name")) {
-	  if (wpa->last != NULL) {
-	    wp->name = g_strdup (g_strstrip (wpa->last->content));
+	  if (wpa->last != NULL && wpa->last->content != NULL) {
+	    nodelang = xmlNodeGetLang (wpa->last);
+
+	    if (wp->name == NULL && nodelang == NULL) {
+	       wp->name = g_strdup (g_strstrip (wpa->last->content));
+            } else {
+	       for (i = 0; syslangs[i] != NULL; i++) {
+	         if (!strcmp (syslangs[i], nodelang)) {
+	           wp->name = g_strdup (g_strstrip (wpa->last->content));
+	         }
+	       }
+	    }
+
+	    xmlFree (nodelang);
+	  } else {
+	    break;
 	  }
 	} else if (!strcmp (wpa->name, "imguri")) {
 	  if (wpa->last != NULL) {
@@ -150,11 +174,15 @@ static void gnome_wp_xml_load_xml (GnomeWPCapplet * capplet,
 	}
       }
 
-      /* Make sure we don't already have this one */
-      item = g_hash_table_lookup (capplet->wphash, wp->filename);
+      /* Make sure we don't already have this one and that filename exists */
+      if (wp->filename != NULL) {
+	item = g_hash_table_lookup (capplet->wphash, wp->filename);
 
-      if (item != NULL) {
-	gnome_wp_item_free (wp);
+	if (item != NULL) {
+	  gnome_wp_item_free (wp);
+	  continue;
+	}
+      } else {
 	continue;
       }
 
